# Function reference {.doc .doc-index}

## Getting Started

Introduction to the package.

## Some functions

Functions to inspect docstrings.

| | |
| --- | --- |
| [aj](aj.qmd#polarstate.aj) |  |
| [predict](predict.qmd#polarstate.predict) |  |